@@ -12,6 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from http import client as http_client
 import json
 
 import mock
@@ -29,13 +30,16 @@ class VirtualMediaTestCase(base.TestCase):
         self.conn = mock.Mock()
         with open('sushy/tests/unit/json_samples/'
                   'virtual_media.json') as f:
-            self.conn.get.return_value.json.return_value = json.load(f)
+            self.json_doc = json.load(f)
+
+        self.conn.get.return_value.json.return_value = self.json_doc
+
         self.sys_virtual_media = virtual_media.VirtualMedia(
             self.conn, '/redfish/v1/Managers/BMC/VirtualMedia/Floppy1',
             redfish_version='1.0.2')
 
     def test__parse_atrtributes(self):
-        self.sys_virtual_media._parse_attributes()
+        self.sys_virtual_media._parse_attributes(self.json_doc)
         self.assertEqual('Virtual Removable Media',
                          self.sys_virtual_media.name)
         self.assertEqual('Floppy1', self.sys_virtual_media.identity)
@@ -83,3 +87,29 @@ class VirtualMediaTestCase(base.TestCase):
             ("/redfish/v1/Managers/BMC/VirtualMedia/Floppy1/Actions"
              "/VirtualMedia.EjectMedia"))
         self.assertTrue(self.sys_virtual_media._is_stale)
+
+    def test_eject_media_pass_empty_dict_415(self):
+        target_uri = ("/redfish/v1/Managers/BMC/VirtualMedia/Floppy1/Actions"
+                      "/VirtualMedia.EjectMedia")
+        self.conn.post.side_effect = [exceptions.HTTPError(
+            method='POST', url=target_uri, response=mock.MagicMock(
+                status_code=http_client.UNSUPPORTED_MEDIA_TYPE)), '200']
+        self.sys_virtual_media.eject_media()
+        post_calls = [
+            mock.call(target_uri),
+            mock.call(target_uri, data={})]
+        self.sys_virtual_media._conn.post.assert_has_calls(post_calls)
+        self.assertTrue(self.sys_virtual_media._is_stale)
+
+    def test_eject_media_pass_empty_dict_400(self):
+        target_uri = ("/redfish/v1/Managers/BMC/VirtualMedia/Floppy1/Actions"
+                      "/VirtualMedia.EjectMedia")
+        self.conn.post.side_effect = [exceptions.HTTPError(
+            method='POST', url=target_uri, response=mock.MagicMock(
+                status_code=http_client.BAD_REQUEST)), '200']
+        self.sys_virtual_media.eject_media()
+        post_calls = [
+            mock.call(target_uri),
+            mock.call(target_uri, data={})]
+        self.sys_virtual_media._conn.post.assert_has_calls(post_calls)
+        self.assertTrue(self.sys_virtual_media._is_stale)
