@@ -45,7 +45,7 @@ class SessionServiceTestCase(base.TestCase):
                 'GET', 'any_url', mock.MagicMock()))
         sessionservice.SessionService(
             self.conn, '/redfish/v1/SessionService', redfish_version='1.0.2')
-        self.assertTrue(mock_LOG.warning.called)
+        self.assertTrue(mock_LOG.debug.called)
 
     def test__parse_attributes(self):
         self.sess_serv_inst._parse_attributes(self.json_doc)
@@ -96,10 +96,8 @@ class SessionServiceTestCase(base.TestCase):
             session_uri)
         uri = self.sess_serv_inst.path + '/Sessions'
         data = {'UserName': 'foo', 'Password': 'secret'}
-        headers = {'X-Auth-Token': None}
         self.conn.post.assert_called_once_with(uri,
-                                               data=data,
-                                               headers=headers)
+                                               data=data)
 
     def test_create_session_missing_x_auth_token(self):
         with open('sushy/tests/unit/json_samples/'
