@@ -14,12 +14,11 @@
 #    under the License.
 
 import copy
+from http import client as http_client
 import io
 import json
 import mock
 
-from six.moves import http_client
-
 from sushy import exceptions
 from sushy.resources import base as resource_base
 from sushy.tests.unit import base
@@ -47,7 +46,7 @@ BASE_RESOURCE_JSON = {
 
 class BaseResource(resource_base.ResourceBase):
 
-    def _parse_attributes(self):
+    def _parse_attributes(self, json_doc):
         pass
 
 
@@ -167,19 +166,22 @@ class ResourceBaseTestCase(base.TestCase):
 class TestResource(resource_base.ResourceBase):
     """A concrete Test Resource to test against"""
 
-    def __init__(self, connector, identity, redfish_version=None):
+    def __init__(self, connector, identity, redfish_version=None,
+                 registries=None):
         """Ctor of TestResource
 
         :param connector: A Connector instance
         :param identity: The id of the Resource
         :param redfish_version: The version of RedFish. Used to construct
             the object according to schema of the given version.
+        :param registries: Dict of Redfish Message Registry objects to be
+            used in any resource that needs registries to parse messages.
         """
         super(TestResource, self).__init__(connector, 'Fakes/%s' % identity,
-                                           redfish_version)
+                                           redfish_version, registries)
         self.identity = identity
 
-    def _parse_attributes(self):
+    def _parse_attributes(self, json_doc):
         pass
 
 
@@ -190,15 +192,17 @@ class TestResourceCollection(resource_base.ResourceCollectionBase):
     def _resource_type(self):
         return TestResource
 
-    def __init__(self, connector, redfish_version=None):
+    def __init__(self, connector, redfish_version=None, registries=None):
         """Ctor of TestResourceCollection
 
         :param connector: A Connector instance
         :param redfish_version: The version of RedFish. Used to construct
             the object according to schema of the given version.
+        :param registries: Dict of Redfish Message Registry objects to be
+            used in any resource that needs registries to parse messages.
         """
-        super(TestResourceCollection, self).__init__(connector, 'Fakes',
-                                                     redfish_version)
+        super(TestResourceCollection, self).__init__(
+            connector, 'Fakes', redfish_version, registries)
 
 
 class ResourceCollectionBaseTestCase(base.TestCase):
@@ -207,7 +211,7 @@ class ResourceCollectionBaseTestCase(base.TestCase):
         super(ResourceCollectionBaseTestCase, self).setUp()
         self.conn = mock.MagicMock()
         self.test_resource_collection = TestResourceCollection(
-            self.conn, redfish_version='1.0.x')
+            self.conn, redfish_version='1.0.x', registries=None)
         self.conn.reset_mock()
 
     def test_get_member(self):
@@ -227,7 +231,7 @@ class ResourceCollectionBaseTestCase(base.TestCase):
         self.test_resource_collection.members_identities = ('1',)
         self.conn.get.side_effect = exceptions.ResourceNotFoundError(
             method='GET', url='http://foo.bar:8000/redfish/v1/Fakes/2',
-            response=mock.Mock(status_code=http_client.NOT_FOUND))
+            response=mock.MagicMock(status_code=http_client.NOT_FOUND))
         # | WHEN & THEN |
         self.assertRaises(exceptions.ResourceNotFoundError,
                           self.test_resource_collection.get_member, '2')
@@ -289,7 +293,7 @@ class ResourceCollectionBaseTestCase(base.TestCase):
 TEST_JSON = {
     'String': 'a string',
     'Integer': '42',
-    'List': ['a string', 42],
+    'MappedList': ['raw1', 'raw2', 'raw'],
     'Nested': {
         'String': 'another string',
         'Integer': 0,
@@ -316,7 +320,9 @@ TEST_JSON = {
 
 
 MAPPING = {
-    'raw': 'real'
+    'raw': 'real',
+    'raw1': 'real1',
+    'raw2': 'real2'
 }
 
 
@@ -342,6 +348,7 @@ class ComplexResource(resource_base.ResourceBase):
     string = resource_base.Field('String', required=True)
     integer = resource_base.Field('Integer', adapter=int)
     nested = NestedTestField('Nested')
+    mapped_list = resource_base.MappedListField('MappedList', MAPPING)
     field_list = TestListField('ListField')
     dictionary = TestDictionaryField('Dictionary')
     non_existing_nested = NestedTestField('NonExistingNested')
@@ -366,6 +373,8 @@ class FieldTestCase(base.TestCase):
         self.assertEqual('field value', self.test_resource.nested.nested_field)
         self.assertEqual('real', self.test_resource.nested.mapped)
         self.assertEqual(3.14, self.test_resource.nested.non_existing)
+        self.assertEqual(['real1', 'real2', 'real'],
+                         self.test_resource.mapped_list)
         self.assertEqual('a third string',
                          self.test_resource.field_list[0].string)
         self.assertEqual(2, self.test_resource.field_list[1].integer)
@@ -431,3 +440,24 @@ class FieldTestCase(base.TestCase):
         # Regular attributes cannot be accessed via mapping
         self.assertRaisesRegex(KeyError, '_load', lambda: field['_load'])
         self.assertRaisesRegex(KeyError, '__init__', lambda: field['__init__'])
+
+
+class PartialKeyResource(resource_base.ResourceBase):
+    string = resource_base.Field(
+        lambda key, **context: key.startswith('Str'))
+    integer = resource_base.Field(
+        lambda key, value, **context: key == 'Integer' and int(value) < 42)
+
+
+class FieldPartialKeyTestCase(base.TestCase):
+    def setUp(self):
+        super(FieldPartialKeyTestCase, self).setUp()
+        self.conn = mock.Mock()
+        self.json = copy.deepcopy(TEST_JSON)
+        self.conn.get.return_value.json.return_value = self.json
+        self.test_resource = PartialKeyResource(
+            self.conn, redfish_version='1.0.x')
+
+    def test_ok(self):
+        self.assertEqual('a string', self.test_resource.string)
+        self.assertIsNone(self.test_resource.integer)
